### Hexlet tests and linter status:
[![Actions Status](https://github.com/WeibHai/python-project-50/workflows/hexlet-check/badge.svg)](https://github.com/WeibHai/python-project-50/actions)

<a href="https://codeclimate.com/github/WeibHai/python-project-50/maintainability"><img src="https://api.codeclimate.com/v1/badges/0879bbf43057d1a6bbc1/maintainability" /></a>

<a href="https://codeclimate.com/github/WeibHai/python-project-50/test_coverage"><img src="https://api.codeclimate.com/v1/badges/0879bbf43057d1a6bbc1/test_coverage" /></a>

Comparison of deep nested files formatter mode - stylish (JSON and YML) - asciinema https://asciinema.org/a/I4SYMHBrQ6HbzhbMwZSCw82Ed

Comparison of deep nested files formatter mode - plain (JSON and YML) - asciinema https://asciinema.org/a/KFm70M6D6LrZq4V2tWBmMwTiM

Flat JSON file comparison - asciinema https://asciinema.org/a/KXMf4zAZtkXZcyGCEXKNfbTA4

Flat YML file comparison - asciinema https://asciinema.org/a/BnpoQyXUH3P0Tw3UsiiDXQYMe